@@ -64,4 +64,8 @@ def prune_archives(
         + (repository,)
     )
 
-    execute_command(full_command, output_log_level=logging.WARNING if stats else logging.INFO)
+    execute_command(
+        full_command,
+        output_log_level=logging.WARNING if stats else logging.INFO,
+        error_on_warnings=False,
+    )
