@@ -15,7 +15,9 @@ from borgmatic.borg import extract as borg_extract
 from borgmatic.borg import info as borg_info
 from borgmatic.borg import init as borg_init
 from borgmatic.borg import list as borg_list
+from borgmatic.borg import mount as borg_mount
 from borgmatic.borg import prune as borg_prune
+from borgmatic.borg import umount as borg_umount
 from borgmatic.commands.arguments import parse_arguments
 from borgmatic.config import checks, collect, convert, validate
 from borgmatic.hooks import command, dispatch, dump, monitor
@@ -246,6 +248,27 @@ def run_actions(
                 destination_path=arguments['extract'].destination,
                 progress=arguments['extract'].progress,
             )
+    if 'mount' in arguments:
+        if arguments['mount'].repository is None or repository == arguments['mount'].repository:
+            logger.info('{}: Mounting archive {}'.format(repository, arguments['mount'].archive))
+            borg_mount.mount_archive(
+                repository,
+                arguments['mount'].archive,
+                arguments['mount'].mount_point,
+                arguments['mount'].paths,
+                arguments['mount'].foreground,
+                arguments['mount'].options,
+                storage,
+                local_path=local_path,
+                remote_path=remote_path,
+            )
+    if 'umount' in arguments:
+        logger.info(
+            '{}: Unmounting mount point {}'.format(repository, arguments['umount'].mount_point)
+        )
+        borg_umount.unmount_archive(
+            mount_point=arguments['umount'].mount_point, local_path=local_path
+        )
     if 'restore' in arguments:
         if arguments['restore'].repository is None or repository == arguments['restore'].repository:
             logger.info(
@@ -392,11 +415,9 @@ def make_error_log_records(message, error=None):
     except CalledProcessError as error:
         yield log_record(levelno=logging.CRITICAL, levelname='CRITICAL', msg=message)
         if error.output:
+            # Suppress these logs for now and save full error output for the log summary at the end.
             yield log_record(
-                levelno=logging.CRITICAL,
-                levelname='CRITICAL',
-                msg=error.output,
-                suppress_log=bool(logger.getEffectiveLevel() < logging.WARNING),
+                levelno=logging.CRITICAL, levelname='CRITICAL', msg=error.output, suppress_log=True
             )
         yield log_record(levelno=logging.CRITICAL, levelname='CRITICAL', msg=error)
     except (ValueError, OSError) as error:
@@ -423,6 +444,8 @@ def collect_configuration_run_summary_logs(configs, arguments):
         repository = arguments['extract'].repository
     elif 'list' in arguments and arguments['list'].archive:
         repository = arguments['list'].repository
+    elif 'mount' in arguments:
+        repository = arguments['mount'].repository
     else:
         repository = None
 
@@ -543,16 +566,18 @@ def main():  # pragma: no cover
     logger.debug('Ensuring legacy configuration is upgraded')
     convert.guard_configuration_upgraded(LEGACY_CONFIG_PATH, config_filenames)
 
-    summary_logs = list(collect_configuration_run_summary_logs(configs, arguments))
+    summary_logs = parse_logs + list(collect_configuration_run_summary_logs(configs, arguments))
+    summary_logs_max_level = max(log.levelno for log in summary_logs)
 
-    if logger.getEffectiveLevel() < logging.WARNING:
-        logger.info('')
-        logger.info('summary:')
-        [
-            logger.handle(log)
-            for log in parse_logs + summary_logs
-            if log.levelno >= logger.getEffectiveLevel()
-        ]
+    for message in ('', 'summary:'):
+        log_record(
+            levelno=summary_logs_max_level,
+            levelname=logging.getLevelName(summary_logs_max_level),
+            msg=message,
+        )
 
-    if any(log.levelno == logging.CRITICAL for log in summary_logs):
+    for log in summary_logs:
+        logger.handle(log)
+
+    if summary_logs_max_level >= logging.CRITICAL:
         exit_with_help_link()
